@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "doom-themes" "2.3.0"
+(define-package "doom-themes" "20250924.2042"
   "An opinionated pack of modern color-themes."
   '((emacs  "25.1")
     (cl-lib "0.5"))
   :url "https://github.com/doomemacs/themes"
-  :commit "d79a41f593c69697af1ddaac971c0c47ecc446a8"
-  :revdesc "v2.3.0-0-gd79a41f593c6"
+  :commit "376cf4bdd7d296a3da94aa9a6c68761e7c38a252"
+  :revdesc "376cf4bdd7d2"
   :keywords '("themes" "faces")
   :authors '(("Henrik Lissner" . "contact@henrik.io"))
   :maintainers '(("Henrik Lissner" . "contact@henrik.io")))
